@@ -194,7 +194,7 @@ void apply_server_settings(struct w *widgets)
     /* Add entry settings to options buffer */
     for(i=0; i<=36; i++)
     {
-        value = g_strdup_printf(gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[i])));
+        value = g_strdup_printf("%s", gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[i])));
         if( value==NULL || strlen(value) < 1 )
 	{
 //	    printf("Entry %d skipped. Input too short\n", i);
@@ -287,7 +287,7 @@ void apply_server_settings(struct w *widgets)
 	if( i > 57 && i < 64 )
 	  continue;
 
-        value = g_strdup_printf(gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[i])));
+        value = g_strdup_printf("%s", gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[i])));
         if( value==NULL || strlen(value) < 1 )
 	{
 //	    printf("Spinbutton %d skipped. Input too short\n", i);
@@ -441,7 +441,7 @@ void apply_server_settings(struct w *widgets)
     	if( i == 71 )
 	  snprintf(opt_line, 1000, "high_page_fault_warning %s\n", value);
     	if( i == 72 )
-	  snprintf(opt_line, 1000, "high_memory_warning %s bytes\n", value);
+	  snprintf(opt_line, 1000, "high_memory_warning %s MB\n", value);
     	if( i == 73 )
 	  snprintf(opt_line, 1000, "sleep_after_fork %s\n", value);
     	if( i == 74 )
