@@ -21,6 +21,7 @@
 
 
 #include <gtk/gtk.h>
+#include <glib.h>
 #include <stdio.h>
 #include <string.h>
 #include "widgets.h"
@@ -110,20 +111,46 @@ void delete_row_clicked(gpointer data, GtkTreeView *treeview)
     }
 }
 
-/* Populate acl_combo_list_1 in the second treeview
-   with the contents of the first treeview's ACL Name list */
+/* Populate acl_combo_list_3 in the second treeview
+   with the contents of the first treeview's ACL Name list.
+   Dont add duplicate ACL name entries. */
 gboolean names_foreach(GtkTreeModel *model, GtkTreePath *path,
         		  GtkTreeIter *iter, char *unused)
 {
-    GtkTreeIter new_iter;
-    gchar *acl_name;
+    GtkTreeIter list_iter, new_iter;
+    gchar *list_name, *acl_name;
+    int acl_name_exists = 0;
 
     gtk_tree_model_get(model, iter, 0, &acl_name, -1);
 
-    if( acl_name !=NULL )
+    if( acl_name != NULL )
     {
-	gtk_list_store_append(acl_combo_list[3], &new_iter);
-	gtk_list_store_set(acl_combo_list[3], &new_iter, 0, acl_name, -1);
+	/* Check if this acl name has already been added to the combo */            
+	if( gtk_tree_model_get_iter_first(GTK_TREE_MODEL(acl_combo_list[3]), &list_iter) )
+        {
+            do {
+                    gtk_tree_model_get(GTK_TREE_MODEL(acl_combo_list[3]), &list_iter, 0, &list_name, -1);
+                    if( list_name )
+    		    {
+                        if( strcmp(acl_name, list_name) == 0 )
+                        {
+			    acl_name_exists = 1;
+			    break;
+                        }
+                    }
+                    if( list_name!=NULL )
+                      g_free(list_name);
+               
+	       }    while(gtk_tree_model_iter_next(GTK_TREE_MODEL(acl_combo_list[3]), &list_iter));
+        }
+
+	if( ! acl_name_exists )
+	{
+	    gtk_list_store_append(acl_combo_list[3], &new_iter);
+	    gtk_list_store_set(acl_combo_list[3], &new_iter, 0, acl_name, -1);
+	}
+
+	g_free(acl_name);
     }
 
     return FALSE;
@@ -153,7 +180,7 @@ void text_cell_edited(GtkCellRendererText *cell, gchar *path_string,
     /* Changes the edited cells text */
     GtkTreeIter iter;
     GtkTreePath *path = NULL;
-    int column = (int) g_object_get_data(G_OBJECT(cell), "column");
+    int column = (gint)  (glong) g_object_get_data(G_OBJECT(cell), "column");
 
     path = gtk_tree_path_new_from_string(path_string);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(store), &iter, path);
@@ -178,7 +205,7 @@ void combo_cell_edited(GtkCellRendererText *cell, gchar *path_string,
     /* Changes cell combo text */
     GtkTreeIter iter;
     GtkTreePath *path = NULL;
-    int column = (int) g_object_get_data(G_OBJECT(cell), "column");
+    int column = (gint)  (glong) g_object_get_data(G_OBJECT(cell), "column");
 
     path = gtk_tree_path_new_from_string(path_string);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(store), &iter, path);
@@ -192,8 +219,6 @@ void combo_cell_edited(GtkCellRendererText *cell, gchar *path_string,
 
 void create_acl_tab(struct w *widgets)
 {
-    GtkWidget *main_scrolled_window;
-    GtkWidget *main_vbox;
     GtkWidget *hbox[NUM_HBOXES];
     GtkTooltips *tooltips;
     gchar *utf8=NULL;
@@ -211,24 +236,16 @@ void create_acl_tab(struct w *widgets)
 
     tooltips = gtk_tooltips_new();
 
-    /* Create the main scrolled window in the notebook */
-    main_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), main_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(main_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
-    /* Must set a larger size or it wont scroll */
-    gtk_widget_set_size_request(main_scrolled_window, -1, 100);
-
-    /* Create a main vbox inside the main scrolled window */
-    main_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(main_scrolled_window), main_vbox);
-
-    /* Pack hboxes into the main vbox */
+    /* Pack hboxes into the vbox */
     for(i=0; i<NUM_HBOXES; i++)
     {
 	hbox[i] = gtk_hbox_new(TRUE, 0);
-	gtk_container_add(GTK_CONTAINER(main_vbox), hbox[i]);
+
+	/* Button box containers should not expand */
+	if( i == 1 || i == 3 )
+	  gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), hbox[i], FALSE, TRUE, 0);
+	else
+	  gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), hbox[i], TRUE, TRUE, 0);
     }  
 
     /* Create text/editable cell renderers */
@@ -281,7 +298,7 @@ void create_acl_tab(struct w *widgets)
 
     /* ACL button box */
     GtkWidget *acl_button_box = gtk_hbutton_box_new();
-    gtk_box_pack_start(GTK_BOX(hbox[1]), acl_button_box, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox[1]), acl_button_box, FALSE, TRUE, 0);
     gtk_button_box_set_layout(GTK_BUTTON_BOX(acl_button_box), GTK_BUTTONBOX_SPREAD);
 
     /* Delete button */
@@ -306,7 +323,7 @@ void create_acl_tab(struct w *widgets)
 
     /* ACL Permissions TREEVIEW BEGIN */
     aclperm_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-    gtk_box_pack_start(GTK_BOX(hbox[2]), aclperm_scrolled_window, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox[2]), aclperm_scrolled_window, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(aclperm_scrolled_window), 
 						    GTK_POLICY_AUTOMATIC, 
 						    GTK_POLICY_ALWAYS);
@@ -332,7 +349,7 @@ void create_acl_tab(struct w *widgets)
 
     /* AddType/Application type button box */
     GtkWidget *aclperm_button_box = gtk_hbutton_box_new();
-    gtk_box_pack_start(GTK_BOX(hbox[3]), aclperm_button_box, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox[3]), aclperm_button_box, FALSE, TRUE, 0);
     gtk_button_box_set_layout(GTK_BUTTON_BOX(aclperm_button_box), GTK_BUTTONBOX_SPREAD);
 
     /* Delete button */
