@@ -63,7 +63,7 @@ void create_server_settings(struct w *widgets)
     /* visible_hostname */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Visible hostname: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Anything works here, IE: www.example.org"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A visible hostname, IE: www.example.org"), NULL);
     a++; b++; ent++;
 
     /* mail_from */
@@ -75,7 +75,7 @@ void create_server_settings(struct w *widgets)
     /* client_netmask */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Client netmask: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The clients netmask IE: 255.255.255.255"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The clients netmask IE: 255.255.255.0"), NULL);
     a++; b++; ent++;
 
     /* check_hostnames */
@@ -310,7 +310,7 @@ void create_server_settings(struct w *widgets)
     /* hierarchy_stoplist */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Hierarchy stoplist: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: A stoplist"), NULL);
     a++; b++; ent++;
 
     /* access_log */
@@ -352,37 +352,37 @@ void create_server_settings(struct w *widgets)
     /* icon_directory */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Icon directory: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Icon directory path"), NULL);
     a++; b++; ent++;
 
     /* error_directory */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Error directory: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Error directory path"), NULL);
     a++; b++; ent++;
 
     /* diskd_program */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Diskd program: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Path to the diskd program"), NULL);
     a++; b++; ent++;
 
     /* unlinkd_program */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Unlinkd program: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Path to the unlinkd program"), NULL);
     a++; b++; ent++;
 
     /* debug_options */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Debug options: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Debug options"), NULL);
     a++; b++; ent++;
 
     /* ftp_user */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" FTP user: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: hmm"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The FTP user name"), NULL);
     a++; b++; ent++;
 
     /* emulate_httpd_log */
@@ -484,7 +484,7 @@ void create_server_settings(struct w *widgets)
     /* ftp_list_width */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" FTP list width: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("List width for FTP"), NULL);
     a++; b++; spin++;
 
     /* memory_pools */
@@ -886,49 +886,49 @@ void create_server_settings(struct w *widgets)
     /* cache_mgr */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Cache manager: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The cache manager"), NULL);
     a++; b++; ent++;
 
     /* mail_program */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Mail program: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Mail program to use"), NULL);
     a++; b++; ent++;
 
     /* umask */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Umask: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Umask to use"), NULL);
     a++; b++; ent++;
 
     /* request_header_max_size */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Request header max size: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Limit request headers"), NULL);
     a++; b++; spin++;
 
     /* request_body_max_size */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Request body max size: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Limit body sizes"), NULL);
     a++; b++; spin++;
 
     /* quick_abort_min */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Quick abort minimum: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Quick abort on minimum"), NULL);
     a++; b++; spin++;
 
     /* quick_abort_max */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Quick abort maximum: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Quick abort on maximum"), NULL);
     a++; b++; spin++;
 
     /* quick_abort_pct */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Quick abort pct: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("PCT abort"), NULL);
     a++; b++; spin++;
 
     /* read_ahead_gap */
@@ -946,19 +946,19 @@ void create_server_settings(struct w *widgets)
     /* positive_dns_ttl */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Positive DNS TTL: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("DNS time to live"), NULL);
     a++; b++; spin++;
 
     /* negative_dns_ttl */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Negative DNS TTL: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Negative DNS time to live"), NULL);
     a++; b++; spin++;
 
     /* range_offset_limit */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Range offset limit: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("A range offset"), NULL);
     a++; b++; spin++;
 
     /* client_lifetime */
@@ -970,79 +970,79 @@ void create_server_settings(struct w *widgets)
     /* shutdown_lifetime */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Shutdown lifetime: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("A shutdown lifetime"), NULL);
     a++; b++; spin++;
 
     /* reply_header_max_size */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Reply header max size: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Max reply header"), NULL);
     a++; b++; spin++;
 
     /* announce_period */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Announce_period: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Announcement interval"), NULL);
     a++; b++; spin++;
 
     /* announce_port */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Announce_port: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Port to announce to"), NULL);
     a++; b++; spin++;
 
     /* announce_host */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Announce host: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Host to announce to"), NULL);
     a++; b++; ent++;
 
     /* logfile_rotate */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Logfile rotate: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Logfile rotation"), NULL);
     a++; b++; spin++;
 
     /* tcp_recv_bufsize */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" TCP recieve buffer size: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("TCP recive buffer size"), NULL);
     a++; b++; spin++;
 
     /* minimum_direct_hops */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Minimum direct hops: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Minimum direct hops"), NULL);
     a++; b++; spin++;
 
     /* minimum_direct_rtt */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Minimum direct rtt: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Minimum direct RTT"), NULL);
     a++; b++; spin++;
 
     /* store_avg_object_size */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Store average object size: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Storage average object size"), NULL);
     a++; b++; spin++;
 
     /* store_objects_per_bucket */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Store objects per bucket: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Objects per bucket"), NULL);
     a++; b++; spin++;
 
     /* netdb_low */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Net database low: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Net DB low"), NULL);
     a++; b++; spin++;
 
     /* netdb_high */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Net database high: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Net DB high"), NULL);
     a++; b++; spin++;
 
     /* netdb_ping_period */
@@ -1054,37 +1054,37 @@ void create_server_settings(struct w *widgets)
     /* maximum_single_addr_tries */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Maximum single address tries: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Max single address tries"), NULL);
     a++; b++; spin++;
 
     /* as_whois_server */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Use this whois server: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A whois server to use"), NULL);
     a++; b++; ent++;
 
     /* wccp_address */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP address: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Address"), NULL);
     a++; b++; ent++;
 
     /* wccp2_address */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP2 address: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Address"), NULL);
     a++; b++; ent++;
 
     /* wccp_router */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP router: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Router"), NULL);
     a++; b++; ent++;
 
     /* wccp_version */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP version: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Version"), NULL);
     a++; b++; spin++;
 
     /* wccp2_rebuild_wait */
@@ -1102,31 +1102,31 @@ void create_server_settings(struct w *widgets)
     /* wccp2_forwarding_method */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP2 forwarding method: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Forwarding method"), NULL);
     a++; b++; spin++;
 
     /* wccp2_return_method */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP2 return method: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Return method"), NULL);
     a++; b++; spin++;
 
     /* wccp2_assignment_method */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP2 assignment method: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Assignment method"), NULL);
     a++; b++; spin++;
 
     /* wccp2_service (standard) */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP2 service: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Service"), NULL);
     a++; b++; spin++;
 
     /* wccp2_weight */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" WCCP2 weight: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Weight"), NULL);
     a++; b++; spin++;
 
     /* incoming_icp_average */
@@ -1180,7 +1180,7 @@ void create_server_settings(struct w *widgets)
     /* max_open_disk_fds */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Maximum open disk fds: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Max open disk fd's"), NULL);
     a++; b++; spin++;
 
     /* digest_generation */
@@ -1198,301 +1198,92 @@ void create_server_settings(struct w *widgets)
     /* digest_bits_per_entry */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Digest bits per entry: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Digest bits"), NULL);
     a++; b++; spin++;
 
     /* digest_rebuild_period */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Digest rebuild period: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Rebuild period"), NULL);
     a++; b++; spin++;
 
     /* digest_rewrite_period */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Digest rewrite period: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Rewrite period"), NULL);
     a++; b++; spin++;
 
     /* digest_swapout_chunk_size */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Digest swapout chunk size: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Chunk size"), NULL);
     a++; b++; spin++;
 
     /* digest_rebuild_chunk_percentage */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Digest rebuild chunk percentage: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Chunk percentage"), NULL);
     a++; b++; spin++;
 
     /* high_response_time_warning */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" High response time warning: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Warn on high response times"), NULL);
     a++; b++; spin++;
 
     /* high_page_fault_warning */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" High page fault warning: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Warn on high page faults"), NULL);
     a++; b++; spin++;
 
     /* high_memory_warning */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" High memory warning: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Warn if memory usage is higher then this limit in MegaBytes"), NULL);
     a++; b++; spin++;
 
     /* sleep_after_fork */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Sleep after fork: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Sleep after forking"), NULL);
     a++; b++; spin++;
 
     /* Use COMBO ??? store_dir_select_algorithm least-load... */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Store directory selection algorithm: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Algorithm"), NULL);
     a++; b++; ent++;
 
     /* minimum_expiry_time */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Minimum expiry time: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Min expiry time"), NULL);
     a++; b++; spin++;
 
     /* authenticate_cache_garbage_interval */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Authenticate cache garbage interval: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Interval"), NULL);
     a++; b++; spin++;
 
     /* authenticate_ttl */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Authenticate TTL: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("TTL"), NULL);
     a++; b++; spin++;
 
     /* authenticate_ip_ttl */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Authenticate IP TTL: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("IP TTL"), NULL);
     a++; b++; spin++;
 
     /* coredump_dir */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Coredump directory: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Directory for coredumps"), NULL);
     a++; b++; ent++;
 
-
-
-/*
-visible_hostname host.example.org
-check_hostnames on
-mail_from squid@example.org
-client_netmask 255.255.255.255
-icp_query_timeout 0
-maximum_icp_query_timeout 2000
-mcast_icp_query_timeout 2000
-dead_peer_timeout 10 seconds
-forward_timeout 4 minutes
-connect_timeout 1 minute
-peer_connect_timeout 30 seconds
-read_timeout 15 minutes
-request_timeout 5 minutes
-persistent_request_timeout 1 minute
-pconn_timeout 120 seconds
-ident_timeout 10 seconds
-dns_timeout 2 minutes
-dns_retransmit_interval 5 seconds
-dns_defnames off
-### Resolv.conf or dns_nameservers 10.0.0.1 10.0.0.2
-
-snmp_port 0
-snmp_incoming_address 0.0.0.0
-snmp_outgoing_address 255.255.255.255
-udp_incoming_address 0.0.0.0
-udp_outgoing_address 255.255.255.255
-icp_port 3130 proxy-only
-cache_mem 8 MB
-cache_swap_low 90
-cache_swap_high 95
-maximum_object_size 4096 KB
-minimum_object_size 0 KB
-maximum_object_size_in_memory 8 KB
-ipcache_size 1024
-ipcache_low 90
-ipcache_high 95
-fqdncache_size 1024
-cache_replacement_policy lru
-memory_replacement_policy lru
-cache_dir ufs /var/spool/squid 100 16 256
-hierarchy_stoplist cgi-bin ?
-
-access_log /var/log/squid/access.log squid
-cache_log /var/log/squid/cache.log
-cache_store_log /var/log/squid/store.log
-mime_table /etc/squid/mime.conf
-pid_filename /var/run/squid.pid
-hosts_file /etc/hosts
-icon_directory /usr/share/squid/icons
-error_directory /usr/share/squid/errors/English
-diskd_program /usr/lib/squid/diskd-daemon
-unlinkd_program /usr/lib/squid/unlinkd
-
-emulate_httpd_log off
-log_ip_on_direct on
-log_mime_hdrs off
-debug_options ALL,1
-log_fqdn off
-ftp_user Squid@
-ftp_list_width 32
-ftp_passive on
-ftp_sanitycheck on
-ftp_telnet_protocol on
-allow_underscore on
-
-memory_pools on
-memory_pools_limit 5 MB
-acl_uses_indirect_client on
-half_closed_clients on
-httpd_suppress_version_string off
-delay_pool_uses_indirect_client on
-log_uses_indirect_client on
-via on
-forwarded_for on
-log_icp_queries on
-httpd_accel_no_pmtu_disc off
-client_db on
-icp_hit_stale off
-query_icmp off
-test_reachability off
-buffered_logs off
-reload_into_ims off
-global_internal_static on
-short_icon_urls off
-offline_mode off
-uri_whitespace strip
-nonhierarchical_direct on
-prefer_direct off
-strip_query_terms on
-redirector_bypass off
-ignore_unknown_nameservers on
-client_persistent_connections on
-server_persistent_connections on
-persistent_connection_after_error off
-detect_broken_pconn off
-balance_on_multiple_ip on
-pipeline_prefetch off
-request_entities off
-ie_refresh off
-vary_ignore_expire off
-relaxed_header_parser on
-cache_vary on
-retry_on_error off
-collapsed_forwarding off
-
-cache_mgr root
-mail_program mail
-cache_effective_user squid
-cache_effective_group squid
-umask 027
-wais_relay_port 0
-request_header_max_size 20 KB
-request_body_max_size 0 KB
-refresh_pattern ^ftp:           1440    20%     10080
-refresh_pattern ^gopher:        1440    0%      1440
-refresh_pattern .               0       20%     4320
-quick_abort_min 16 KB
-quick_abort_max 16 KB
-quick_abort_pct 95
-read_ahead_gap 16 KB
-negative_ttl 5 minutes
-positive_dns_ttl 6 hours
-negative_dns_ttl 1 minute
-range_offset_limit 0 KB
-refresh_stale_hit 0 seconds
-client_lifetime 1 day
-shutdown_lifetime 30 seconds
-reply_header_max_size 20 KB
-announce_period 0
-announce_host tracker.ircache.net
-announce_port 3131
-logfile_rotate 0
-tcp_recv_bufsize 0 bytes
-minimum_direct_hops 4
-minimum_direct_rtt 400
-store_avg_object_size 13 KB
-store_objects_per_bucket 20
-netdb_low 900
-netdb_high 1000
-netdb_ping_period 5 minutes
-maximum_single_addr_tries 1
-
-as_whois_server whois.ra.net
-wccp_address 0.0.0.0
-wccp2_address 0.0.0.0
-wccp_router 0.0.0.0
-wccp_version 4
-wccp2_rebuild_wait on
-wccp2_forwarding_method 1
-wccp2_return_method 1
-wccp2_assignment_method 1
-wccp2_service standard 0
-wccp2_weight 10000
-incoming_icp_average 6
-incoming_http_average 4
-incoming_dns_average 4
-min_icp_poll_cnt 8
-min_dns_poll_cnt 8
-min_http_poll_cnt 8
-max_open_disk_fds 0
-
-coredump_dir none
-coredump_dir /var/spool/squid
-
-digest_generation on
-digest_bits_per_entry 5
-digest_rebuild_period 1 hour
-digest_rewrite_period 1 hour
-digest_swapout_chunk_size 4096 bytes
-digest_rebuild_chunk_percentage 10
-
-
-high_response_time_warning 0
-high_page_fault_warning 0
-high_memory_warning 0
-store_dir_select_algorithm least-load
-sleep_after_fork 0
-minimum_expiry_time 60 seconds
-max_filedesc 1024
-
-authenticate_cache_garbage_interval 1 hour
-authenticate_ttl 1 hour
-authenticate_ip_ttl 0 seconds
-
----------- The above options have been added -----------
-*/
-
-
-/*
-### Dangerous ###
-#mcast_groups 239.128.16.128 224.0.1.20
-*/
-/*  Treeview ...
-refresh_pattern ^ftp:           1440    20%     10080
-refresh_pattern ^gopher:        1440    0%      1440
-refresh_pattern .               0       20%     4320
-*/
-
-
-
-// Fixme, remove later...
-    /* Padding */
-    widgets->server_set_spinbutton[spin] = make_padded_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table), _(""), 0,1,a,b,50);
-
-//    gtk_widget_hide(GTK_WIDGET(widgets->server_set_spinbutton[spin]));
-
     gtk_widget_show_all(widgets->main_window);
 }
