@@ -20,6 +20,7 @@
 
 
 #include <gtk/gtk.h>
+#include <glib.h>
 #include <stdio.h>
 #include <string.h>
 #include "widgets.h"
@@ -93,7 +94,7 @@ void server_text_cell_edited(GtkCellRendererText *cell, gchar *path_string,
     /* Changes the edited cells text */
     GtkTreeIter iter;
     GtkTreePath *path = NULL;
-    int column = (int) g_object_get_data(G_OBJECT(cell), "column");
+    int column = (gint)  (glong) g_object_get_data(G_OBJECT(cell), "column");
 
     path = gtk_tree_path_new_from_string(path_string);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(store), &iter, path);
