@@ -133,11 +133,11 @@ return; // For now
     /* Get everything except the selected users settings and allowuser in the selected server */
 
     if( strstr((char *)global_server_type, "Virtualhost") )
-       sprintf(address_buffer, "<VirtualHost %s>", global_server_address);
+       snprintf(address_buffer, 4000, "<VirtualHost %s>", global_server_address);
     else
-       sprintf(address_buffer, global_server_address);
+       snprintf(address_buffer, 4000, "%s", global_server_address);
      
-    sprintf(port_buffer, "Port %s", global_server_port);
+    snprintf(port_buffer, 4000, "Port %s", global_server_port);
 
 
     /* Standard server selected, delete the selected user in this (first) server */
