@@ -107,9 +107,9 @@ user_exists(G_CONST_RETURN gchar *username)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", check_buffer);
 			tempname[x]='\0';
-			if( ! strcmp(username, tempname) )
+			if( strcmp(username, tempname) == 0 )
 			{
 			    user_exists = 1;
 			    break;
@@ -145,7 +145,7 @@ user_exists(G_CONST_RETURN gchar *username)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strstr(username, tempname) 
 			&& strlen(username) == strlen(tempname) )
@@ -195,9 +195,9 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", check_buffer);
 			tempname[x]='\0';
-			if( ! strcmp(groupname, tempname) )
+			if( strcmp(groupname, tempname) == 0 )
 			{
 			    group_exists = 1;
 			    break;
@@ -230,7 +230,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strstr(groupname, tempname) && strlen(groupname)==strlen(tempname) )
 			{
@@ -272,7 +272,6 @@ gchar *get_user_setting(gchar *user, gchar *what)
     if( strstr(what, "shell") )
       val_pos = 6;
                                                                         
-                                                                    
     tempname = allocate(4096);
                                                                             
     if((fp=fopen(GH_PASSWD,"r"))==NULL)
