@@ -44,7 +44,7 @@ void populate_cache_tab(struct w *widgets)
     GtkTreePath *path;
     gboolean edit=0;
     int found = 0;
-    gchar *utf8=NULL, *info=NULL, *cache_log;
+    gchar *utf8=NULL, *cache_log;
 
     /* Default to the configured cache log */
     cache_log = g_strdup_printf("%s", CACHE_LOG);
@@ -54,11 +54,6 @@ void populate_cache_tab(struct w *widgets)
     if((fp=fopen(cache_log, "r"))==NULL) 
     {
 	/* Dont show a popup */
-/*        info = g_strdup_printf(_("Cant open the cache log here:\n%s\n"), cache_log);
-	show_info(info);
-	g_free(info);
-	g_free(cache_log);
-*/
         return;
     }
     fseek(fp, 0, SEEK_END);
