@@ -190,8 +190,8 @@ void add_standard_conf(struct w *widgets)
     "cache_store_log /var/log/squid/store.log\n",
     "pid_filename /var/run/squid.pid\n",
     "hosts_file /etc/hosts\n",
-    "diskd_program /usr/lib/squid/diskd-daemon\n",
-    "unlinkd_program /usr/lib/squid/unlinkd\n",
+    "diskd_program ", LIBDIR, "/squid/diskd-daemon\n",
+    "unlinkd_program ", LIBDIR, "/squid/unlinkd\n",
     "emulate_httpd_log off\n",
     "log_ip_on_direct on\n",
     "log_mime_hdrs off\n",
@@ -264,7 +264,7 @@ void add_standard_conf(struct w *widgets)
     "icon_directory /usr/share/squid/icons\n",
     "global_internal_static on\n",
     "short_icon_urls off\n",
-    "error_directory /usr/share/squid/errors/English\n",
+    "error_directory /usr/share/squid/errors/en\n",
     "maximum_single_addr_tries 1\n",
     "retry_on_error off\n",
     "snmp_port 0\n",
@@ -306,7 +306,7 @@ void add_standard_conf(struct w *widgets)
     "request_entities off\n",
     "high_response_time_warning 0\n",
     "high_page_fault_warning 0\n",
-    "high_memory_warning 30 bytes\n",
+    "high_memory_warning 60 MB\n",
     "store_dir_select_algorithm least-load\n",
     "ie_refresh off\n",
     "vary_ignore_expire off\n",
@@ -314,8 +314,9 @@ void add_standard_conf(struct w *widgets)
     "minimum_expiry_time 60 seconds\n",
     "relaxed_header_parser on\n",
     "\n\n",
-    "acl our_networks src 192.168.0.0/24 192.168.1.0/24\n",
-    "acl localhost src 127.0.0.1/255.255.255.255\n",
+
+    "acl our_networks src 192.168.0.0/24 192.168.1.0/24 10.8.0.0/32\n",
+    "acl localhost src 127.0.0.1/32\n",
     "acl to_localhost dst 127.0.0.0/8\n",
     "acl manager proto cache_object\n",
     "acl QUERY urlpath_regex cgi-bin \\?\n",
@@ -333,6 +334,7 @@ void add_standard_conf(struct w *widgets)
     "acl Safe_ports port 777		# multiling http\n",
     "acl CONNECT method CONNECT\n",
     "\n",
+
     "http_access allow localhost\n",
     "http_access allow our_networks\n",
     "http_reply_access allow all\n",
