@@ -49,7 +49,7 @@ char * get_process_pid(char process[1024])
 
     pid = allocate(1024);
     strcpy(pid, "None");
-    
+
     sub_proc_path = allocate(1024);
 
     num = scandir(PROC_PATH, &namelist, 0, alphasort);
@@ -106,6 +106,7 @@ char * get_process_pid(char process[1024])
 int status_update(struct w *widgets)
 {
     gchar *info, *utf8=NULL;
+    GdkColor color;
     char *pid;
 
     pid = get_process_pid("squid");
@@ -117,15 +118,21 @@ int status_update(struct w *widgets)
 	utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 	gtk_label_set_text(GTK_LABEL(widgets->status_label), utf8);
 	g_free(info);
+	/* Set status color */
+	gdk_color_parse("red", &color);
+	gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);
     }
     else
       {
 	  activated = 1;
 	  /* printf("squid is running as pid: %s\n", pid); */
 	  info = g_strdup_printf(_("Status: Activated"));
-    	  utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-    	  gtk_label_set_text(GTK_LABEL(widgets->status_label), utf8);
+	  utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+	  gtk_label_set_text(GTK_LABEL(widgets->status_label), utf8);
 	  g_free(info);
+	  /* Set status color */
+	  gdk_color_parse("dark green", &color);
+	  gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);
       }
     free(pid);
 
